==> kubernetes-model-core-5.7.4-sources.jar: io/fabric8/kubernetes/api/model/HostAliasFluent.java <==
package io.fabric8.kubernetes.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface HostAliasFluent<A extends io.fabric8.kubernetes.api.model.HostAliasFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public A addToHostnames(java.lang.Integer index,java.lang.String item);
  public A setToHostnames(java.lang.Integer index,java.lang.String item);
  public A addToHostnames(java.lang.String... items);
  public A addAllToHostnames(java.util.Collection<java.lang.String> items);
  public A removeFromHostnames(java.lang.String... items);
  public A removeAllFromHostnames(java.util.Collection<java.lang.String> items);
  public java.util.List<java.lang.String> getHostnames();
  public java.lang.String getHostname(java.lang.Integer index);
  public java.lang.String getFirstHostname();
  public java.lang.String getLastHostname();
  public java.lang.String getMatchingHostname(java.util.function.Predicate<java.lang.String> predicate);
  public java.lang.Boolean hasMatchingHostname(java.util.function.Predicate<java.lang.String> predicate);
  public A withHostnames(java.util.List<java.lang.String> hostnames);
  public A withHostnames(java.lang.String... hostnames);
  public java.lang.Boolean hasHostnames();
  public A addNewHostname(java.lang.String arg0);
  public java.lang.String getIp();
  public A withIp(java.lang.String ip);
  public java.lang.Boolean hasIp();
  
  /**
   * Method is deprecated. use withIp instead.
   */
  @java.lang.Deprecated
  public A withNewIp(java.lang.String arg0);
  
}

==> kubernetes-model-core-5.12.4-sources.jar: io/fabric8/kubernetes/api/model/HostAliasFluent.java <==
package io.fabric8.kubernetes.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface HostAliasFluent<A extends io.fabric8.kubernetes.api.model.HostAliasFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public A addToHostnames(java.lang.Integer index,java.lang.String item);
  public A setToHostnames(java.lang.Integer index,java.lang.String item);
  public A addToHostnames(java.lang.String... items);
  public A addAllToHostnames(java.util.Collection<java.lang.String> items);
  public A removeFromHostnames(java.lang.String... items);
  public A removeAllFromHostnames(java.util.Collection<java.lang.String> items);
  public java.util.List<java.lang.String> getHostnames();
  public java.lang.String getHostname(java.lang.Integer index);
  public java.lang.String getFirstHostname();
  public java.lang.String getLastHostname();
  public java.lang.String getMatchingHostname(java.util.function.Predicate<java.lang.String> predicate);
  public java.lang.Boolean hasMatchingHostname(java.util.function.Predicate<java.lang.String> predicate);
  public A withHostnames(java.util.List<java.lang.String> hostnames);
  public A withHostnames(java.lang.String... hostnames);
  public java.lang.Boolean hasHostnames();
  public A addNewHostname(java.lang.String arg0);
  public java.lang.String getIp();
  public A withIp(java.lang.String ip);
  public java.lang.Boolean hasIp();
  
  /**
   * Method is deprecated. use withIp instead.
   */
  @java.lang.Deprecated
  public A withNewIp(java.lang.String arg0);
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  
}
